@@ -105,11 +105,11 @@ class Test_Formatter(unittest.TestCase):
 
 
 class ToolError:
-    codes = dict(
-        CustomError=0,
-        ParseFailed=1,
-        ActionFailed=2,
-    )
+    codes = {
+        0: 'CustomError',
+        1: 'ParseFailed',
+        2: 'ActionFailed',
+    }
     CustomError = 0
     ParseFailed = 1
     ActionFailed = 2
@@ -213,7 +213,6 @@ class Tool(object):
         if fname.endswith('.pyc'):
             fname = fname[:-1]
         assert fname.endswith('.py')
-        print 'opening', fname
         print open(fname).read()
 
     def _validate_implementations(self):
